<?php
/**
 *------------------------------------------------------------------------------
 *  iC Library - Library by Jooml!C, for Joomla!
 *------------------------------------------------------------------------------
 * @package     iC Library
 * @subpackage  Fields
 * @copyright   Copyright (c)2012-2016 Cyril Rezé, Jooml!C - All rights reserved
 *
 * @license     GNU General Public License version 3 or later; see LICENSE.txt
 * @author      Cyril Rezé (Lyr!C)
 * @link        http://www.joomlic.com
 *
 * @version     3.6.0 2016-06-13
 * @since       3.6.0
 *------------------------------------------------------------------------------
*/

// No direct access to this file
defined('_JEXEC') or die();

//jimport('joomla.form.formfield');
JFormHelper::loadFieldClass('list');

if (version_compare(JVERSION, '3.0', 'lt'))
{
	jimport('joomla.application.component.modelform');
	jimport('joomla.registry.registry');
}

use Joomla\Registry\Registry;

/**
 * Application :        SITE
 * Registration form :  dates select list/all dates form field
 */
class icagendaFormFieldRegistrationdates extends JFormFieldList
{
	/**
	 * The form field type.
	 *
	 * @var    string
	 * @since   3.6.0
	 */
	protected $type = 'registrationdates';

	/**
	 * Method to get the field label markup.
	 *
	 * @return  string  The field label markup.
	 * @since   3.6.0
	 */
	protected function getLabel()
	{
		$model		= new iCagendaModelRegistration();
		$item		= $model->getItem();
		$typeReg	= $item->params->get('typeReg', '');

		// If custom field override, return custom field title
		if ($this->title) return $this->title;

		return ($typeReg == 1) ? JText::_('ICAGENDA_REGISTRATION_FORM_DATE') : JText::_('ICAGENDA_REGISTRATION_FORM_PERIOD');
	}

	/**
	 * Method to get the field input markup.
	 *
	 * @return  string  The field input markup.
	 * @since   3.6.0
	 */
	protected function getInput()
	{
		$app		= JFactory::getApplication();
		$session	= JFactory::getSession();

		$model		= new iCagendaModelRegistration();
		$item		= $model->getItem();
		$typeReg	= $item->params->get('typeReg', '');

//		$session = JFactory::getSession();
//		$session_date = $session->get('session_date', '');

//		$value = isset($this->value) ? $this->value : '';
//		$value = $session_date ? $session_date : $value;

		// Get date from url if set, and from session if set
		$url_date		= $app->input->get('date', '');
		$session_date	= $session->get('session_date', '');

		if ($url_date)
		{
			$ex_date		= explode('-', $url_date);
			$defaultDate	= $ex_date[0] . '-' . $ex_date[1] . '-' . $ex_date[2] . ' ' . $ex_date[3] . ':' . $ex_date[4] . ':00';
		}
		else
		{
			$defaultDate	= $session_date;
		}

		$value = ! empty($this->value) ? $this->value : $defaultDate;

		$options = array();

		foreach($this->getOptions() as $opt)
		{
			$date_get = explode('@@', $opt);
			$date_value = $date_get[0];
			$date_option = $date_get[1];
//			$options[] = JHTML::_('select.option', $opt->value, $opt->option);
			$options[] = JHtml::_('select.option', $date_value, $date_option);
		}

		// Return Select list of dates
		if ($typeReg == 1)
		{
			return JHtml::_('select.genericlist', $options, $this->name, 'class="select-large"', 'value', 'text', $value);
		}

		// Return for all dates
		else
		{
			$html = '';
			$html.= '<div style="float:left">';

			$EVENT_SINGLE_DATES	= icagendaEvent::displayListSingleDates($item);
			$EVENT_PERIOD		= icagendaEvent::displayPeriodDates($item);

			if ($EVENT_PERIOD)
			{
				$html.= $EVENT_PERIOD;
			}

			if ($EVENT_SINGLE_DATES)
			{
				$html.= $EVENT_SINGLE_DATES;
			}

			$html.= '<input type="hidden" name="period" value="1" />';
			$html.= '</div>';

			return $html;
		}
	}

	/**
	 * Method to get the field options.
	 *
	 * @return	array	The field option objects.
	 * @since	3.6.0
	 */
	protected function getOptions()
	{
		$options = array();

		$jinput = JFactory::getApplication()->input;
		$id = $jinput->getInt('id');

		$db	= JFactory::getDbo();
		$query	= $db->getQuery(true);

		$query->select('e.*');
		$query->from($db->qn('#__icagenda_events') . ' AS e');
		$query->where($db->qn('id') . ' = ' . (int) $id);

		// Get the options.
		$db->setQuery($query);

		$item = $db->loadObject();

		// Check for a database error.
		if ($db->getErrorNum())
		{
			JError::raiseWarning(500, $db->getErrorMsg());
		}

		$options = array();

		if ($item)
		{
			// Convert parameter fields to objects.
			$registry = version_compare(JVERSION, '3.0', 'lt') ? new JRegistry : new Registry;
			$registry->loadString($item->params);

			// Merge Event params to app params
			$item->params = clone JComponentHelper::getParams('com_icagenda');
			$item->params->merge($registry);

			$options = icagendaRegistration::formDatesList($item);
		}

		return $options;
	}
}
